//
// Source code recreated from a .class file by IntelliJ IDEA
// (powered by Fernflower decompiler)
//

package org.webrtc;

import android.util.Log;

import java.util.Arrays;
import java.util.LinkedHashSet;
import org.webrtc.EglBase.Context;

public class CustomDefaultVideoDecoderFactory implements VideoDecoderFactory {
    private static String TAG = "CustomVideoDecoderFactory";
    private final VideoDecoderFactory hardwareVideoDecoderFactory;
    private final VideoDecoderFactory softwareVideoDecoderFactory = new SoftwareVideoDecoderFactory();
    private final VideoDecoderFactory platformSoftwareVideoDecoderFactory;

    public CustomDefaultVideoDecoderFactory(Context eglContext) {
        this.hardwareVideoDecoderFactory = new CustomHardwareVideoDecoderFactory(eglContext);
        this.platformSoftwareVideoDecoderFactory = new PlatformSoftwareVideoDecoderFactory(eglContext);
    }

    CustomDefaultVideoDecoderFactory(VideoDecoderFactory hardwareVideoDecoderFactory) {
        this.hardwareVideoDecoderFactory = hardwareVideoDecoderFactory;
        this.platformSoftwareVideoDecoderFactory = null;
    }

    public VideoDecoder createDecoder(VideoCodecInfo codecType) {
        VideoDecoder hardwareDecoder = this.hardwareVideoDecoderFactory.createDecoder(codecType);

        if(hardwareDecoder != null) {
            Log.i(TAG, "Using decoder hardware:" + hardwareDecoder.getImplementationName());
            return hardwareDecoder;
        } else {
            VideoDecoder softwareDecoder = this.softwareVideoDecoderFactory.createDecoder(codecType);
            if (softwareDecoder == null && this.platformSoftwareVideoDecoderFactory != null) {
                softwareDecoder = this.platformSoftwareVideoDecoderFactory.createDecoder(codecType);
            }
            Log.i(TAG, "Using decoder software");
            return softwareDecoder;
        }
    }

    public VideoCodecInfo[] getSupportedCodecs() {
        LinkedHashSet<VideoCodecInfo> supportedCodecInfos = new LinkedHashSet();
        VideoCodecInfo[] supported_hardware_decoders = this.hardwareVideoDecoderFactory.getSupportedCodecs();
        VideoCodecInfo[] supported_software_decoders = this.softwareVideoDecoderFactory.getSupportedCodecs();
        Log.i(TAG, "Supported hardware decoder list:");
        for(int i = 0; i < supported_hardware_decoders.length; i++) {
            Log.i(TAG, "    Supported hardware decoder codec:" + supported_hardware_decoders[i].getName());
        }
        for(int i = 0; i < supported_software_decoders.length; i++) {
            Log.i(TAG, "    Supported software decoder codec:" + supported_software_decoders[i].getName());
        }
        Log.i(TAG, "End of hardware decoder list");
        supportedCodecInfos.addAll(Arrays.asList(supported_software_decoders));
        supportedCodecInfos.addAll(Arrays.asList(supported_hardware_decoders));
        if (this.platformSoftwareVideoDecoderFactory != null) {
            supportedCodecInfos.addAll(Arrays.asList(this.platformSoftwareVideoDecoderFactory.getSupportedCodecs()));
        }

        return (VideoCodecInfo[])supportedCodecInfos.toArray(new VideoCodecInfo[supportedCodecInfos.size()]);
    }
}
