//
// Source code recreated from a .class file by IntelliJ IDEA
// (powered by Fernflower decompiler)
//

package org.webrtc;

import android.util.Log;

import java.util.Arrays;
import java.util.LinkedHashSet;
import org.webrtc.EglBase.Context;

public class CustomDefaultVideoEncoderFactory implements VideoEncoderFactory {
    private static String TAG = "CustomVideoEncoderFactory";
    private final VideoEncoderFactory hardwareVideoEncoderFactory;
    private final VideoEncoderFactory softwareVideoEncoderFactory = new SoftwareVideoEncoderFactory();

    public CustomDefaultVideoEncoderFactory(Context eglContext, boolean enableIntelVp8Encoder, boolean enableH264HighProfile) {
        this.hardwareVideoEncoderFactory = new CustomHardwareVideoEncoderFactory(eglContext, enableIntelVp8Encoder, enableH264HighProfile);
    }

    CustomDefaultVideoEncoderFactory(VideoEncoderFactory hardwareVideoEncoderFactory) {
        this.hardwareVideoEncoderFactory = hardwareVideoEncoderFactory;
    }

    public VideoEncoder createEncoder(VideoCodecInfo info) {
        VideoEncoder hardwareEncoder = this.hardwareVideoEncoderFactory.createEncoder(info);
        if(hardwareEncoder != null) {
            Log.i(TAG, "Using encoder hardware :" + hardwareEncoder.getImplementationName());
            return hardwareEncoder;
        } else {
            VideoEncoder softwareEncoder = this.softwareVideoEncoderFactory.createEncoder(info);
            Log.i(TAG, "Using encoder software");
            return softwareEncoder;
        }
    }

    public VideoCodecInfo[] getSupportedCodecs() {
        LinkedHashSet<VideoCodecInfo> supportedCodecInfos = new LinkedHashSet();
        VideoCodecInfo[] supported_hardware_encoders = this.hardwareVideoEncoderFactory.getSupportedCodecs();
        VideoCodecInfo[] supported_software_encoders = this.softwareVideoEncoderFactory.getSupportedCodecs();
        Log.i(TAG, "Supported hardware encoder list:");
        for(int i = 0; i < supported_hardware_encoders.length; i++) {
            Log.i(TAG, "    Supported hardware encoder codec:" + supported_hardware_encoders[i].getName());
        }
        for(int i = 0; i < supported_software_encoders.length; i++) {
            Log.i(TAG, "    Supported software encoder codec:" + supported_software_encoders[i].getName());
        }
        Log.i(TAG, "End of hardware encoder list");
        supportedCodecInfos.addAll(Arrays.asList(supported_software_encoders));
        supportedCodecInfos.addAll(Arrays.asList(supported_hardware_encoders));

        return (VideoCodecInfo[])supportedCodecInfos.toArray(new VideoCodecInfo[supportedCodecInfos.size()]);
    }
}
